#
# spec file for package kf6-kcolorscheme
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kcolorscheme
# Full KF6 version (e.g. 6.7.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kcolorscheme
Version:        6.7.0
Release:        1.2
Summary:        Classes to read and interact with KColorScheme
License:        LGPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Codecs) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}

%description
Classes to read and interact with KColorScheme.

%package -n libKF6ColorScheme6
Summary:        Classes to read and interact with KColorScheme
Requires:       kf6-kcolorscheme >= %{version}

%description -n libKF6ColorScheme6
Classes to read and interact with KColorScheme.

%package devel
Summary:        Classes to read and interact with KColorScheme: Build Environment
Requires:       libKF6ColorScheme6 = %{version}
Requires:       cmake(KF6GuiAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(KF6I18n) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}

%description devel
Classes to read and interact with KColorScheme. Development files.

%lang_package -n libKF6ColorScheme6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kcolorscheme6 --with-man --all-name

%ldconfig_scriptlets -n libKF6ColorScheme6

%files
%{_kf6_debugdir}/kcolorscheme.categories

%files -n libKF6ColorScheme6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6ColorScheme.so.*

%files devel
%doc %{_kf6_qchdir}/KF6ColorScheme.*
%{_kf6_cmakedir}/KF6ColorScheme/
%{_kf6_includedir}/KColorScheme/
%{_kf6_libdir}/libKF6ColorScheme.so

%files -n libKF6ColorScheme6-lang -f kcolorscheme6.lang

%changelog
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Follow system color scheme on Linux
  * Fix build against a static Qt
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * use passkey to avoid issues with private constructor
  * Additional public API
  * [kcolorschememanager] Fix crash (kde#492408)
  * add KColorSchemeManager::instance in favor of public constructor
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * bundle essential breeze color schemes as resource
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- No code change since 6.3.0
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * allow to bundle color schemes with applications inside resources
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * gitignore: add VS Code dir
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kcolorscheme
